@@ -15,12 +15,15 @@ class DownloadThread (threading.Thread):
 		self.treeview_name = treeview_name
 		threading.Thread.__init__ (self)
 	def run (self):
+		self.youtube.entry_lock.acquire (True)
 		self.youtube.entry[self.treeview_name] = self.youtube.service.Get (self.url).entry
+		self.youtube.entry_lock.release ()
 
 class YouTube (totem.Plugin):
 	def __init__ (self):
 		totem.Plugin.__init__(self)
 		self.debug = False
+		self.gstreamer_plugins_present = True
 
 		self.max_results = 20
 		self.button_down = False
@@ -31,6 +34,7 @@ class YouTube (totem.Plugin):
 		self.start_index = {}
 		self.results = {} # This is just the number of results from the last pagination query
 		self.entry = {}
+		self.entry_lock = threading.Lock ()
 
 		self.current_treeview_name = ""
 		self.notebook_pages = []
@@ -38,6 +42,23 @@ class YouTube (totem.Plugin):
 		self.vadjust = {}
 		self.liststore = {}
 	def activate (self, totem_object):
+		"""Check for the availability of the flvdemux and soup GStreamer plugins"""
+		bvw_name = totem_object.get_video_widget_backend_name ()
+
+		if bvw_name.find ("GStreamer") != -1:
+			try:
+				import pygst
+				pygst.require ("0.10")
+				import gst
+
+				registry = gst.registry_get_default ()
+				if registry.find_plugin ("flvdemux") == None or registry.find_plugin ("soup") == None:
+					"""This means an error will be displayed when they try to play anything"""
+					self.gstreamer_plugins_present = False
+			except ImportError:
+				"""Do nothing; either it's using xine or python-gstreamer isn't installed"""
+
+		"""Continue loading the plugin as before"""		
 		self.builder = self.load_interface ("youtube.ui", True, totem_object.get_main_window (), self)
 		self.totem = totem_object
 
@@ -72,7 +93,7 @@ class YouTube (totem.Plugin):
 		treeview = self.builder.get_object ("yt_treeview_" + treeview_name)
 		treeview.set_property ("totem", self.totem)
 		treeview.connect ("row-activated", self.on_row_activated)
-		treeview.connect ("starting-video", self.on_starting_video)
+		treeview.connect_after ("starting-video", self.on_starting_video)
 		treeview.insert_column_with_attributes (0, _("Videos"), renderer, thumbnail=0, title=1)
 
 		self.vadjust[treeview_name] = treeview.get_vadjustment ()
@@ -96,6 +117,15 @@ class YouTube (totem.Plugin):
 		self.results["related"] = 0
 		self.get_results ("/feeds/videos/" + urllib.quote (youtube_id) + "/related?max-results=" + str (self.max_results), "related")
 	def on_starting_video (self, treeview, path, user_data):
+		"""Display an error if the required GStreamer plugins aren't installed"""
+		if self.gstreamer_plugins_present == False:
+			self.totem.interface_error_with_link (_("Totem cannot play this type of media (%s) because you do not have the appropriate plugins to handle it.") % _("YouTube"),
+							      _("Please install the necessary plugins and restart Totem to be able to play this media."),
+							      "http://www.gnome.org/projects/totem/#codecs",
+							      _("More information about media plugins"),
+							      self.totem.get_main_window ())
+			return False
+
 		model, rows = treeview.get_selection ().get_selected_rows ()
 		iter = model.get_iter (rows[0])
 		youtube_id = model.get_value (iter, 3)
@@ -107,7 +137,7 @@ class YouTube (totem.Plugin):
 			response = conn.getresponse ()
 		except:
 			print "Could not resolve stream MRL for YouTube video \"" + youtube_id + "\"."
-			return True
+			return False
 
 		if response.status == 303:
 			location = response.getheader("location")
@@ -140,9 +170,21 @@ class YouTube (totem.Plugin):
 		"""Find the last clause in the URL; after the last /"""
 		return url.split ("/").pop ()
 	def populate_list_from_results (self, treeview_name):
-		"""Wait until we have some results to display"""
-		if self.entry[treeview_name] == None or len (self.entry[treeview_name]) == 0:
+		"""Check and acquire the lock"""
+		if self.entry_lock.acquire (False) == False:
 			return True
+
+		"""Return if there are no results (or we've finished)"""
+		if self.entry[treeview_name] == None or len (self.entry[treeview_name]) == 0:
+			"""Revert the cursor"""
+			window = self.vbox.window
+			window.set_cursor (None)
+
+			self.entry[treeview_name] = None
+			self.entry_lock.release ()
+
+			return False
+
 		"""Only do one result at a time, as the thumbnail has to be downloaded; give them a temporary MRL until the real one is resolved before playing"""
 		entry = self.entry[treeview_name].pop (0)
 		self.results[treeview_name] += 1
@@ -150,6 +192,8 @@ class YouTube (totem.Plugin):
 		youtube_id = self.convert_url_to_id (entry.id.text)
 		mrl = "http://www.youtube.com/v/" + urllib.quote (youtube_id)
 
+		self.entry_lock.release ()
+
 		"""Find the thumbnail tag"""
 		for _element in entry.extension_elements:
 			if _element.tag == "group":
@@ -174,15 +218,6 @@ class YouTube (totem.Plugin):
 
 		self.liststore[treeview_name].append ([pixbuf, entry.title.text, mrl, youtube_id])
 
-		"""Have we finished?"""
-		if len (self.entry[treeview_name]) == 0:
-			"""Revert the cursor"""
-			window = self.vbox.window
-			window.set_cursor (None)
-
-			self.entry[treeview_name] = None
-			return False
-
 		return True
 	def on_search_button_clicked (self, button):
 		search_terms = self.search_entry.get_text ()
@@ -210,6 +245,7 @@ class YouTube (totem.Plugin):
 		window = self.vbox.window
 		window.set_cursor (gtk.gdk.Cursor (gtk.gdk.WATCH))
 
+		self.results_downloaded = False
 		DownloadThread (self, url, treeview_name).start ()
 		gobject.idle_add (self.populate_list_from_results, treeview_name)
 
