@@ -5,12 +5,12 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
  * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * version 2 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more priv.
+ * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
  * License along with this library; if not, write to the Free Software
@@ -21,7 +21,7 @@
  * permission are above and beyond the permissions granted by the GPL license
  * Totem is covered by.
  *
- * Monday 7th February 2005: Christian Schaller: Add excemption clause.
+ * Monday 7th February 2005: Christian Schaller: Add exception clause.
  * See license_change file for details.
  *
  */
@@ -31,6 +31,7 @@
 #include "totem-properties-view.h"
 
 #include "bacon-video-widget-properties.h"
+#include "bacon-video-widget.h"
 #include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
 
@@ -96,7 +97,7 @@ on_got_metadata_event (BaconVideoWidget *bvw, TotemPropertiesView *props)
 	gtk_label_set_text (GTK_LABEL (props->priv->label), _(label));
 
 	bacon_video_widget_properties_update
-		(props->priv->props, props->priv->bvw);
+		(props->priv->props, GTK_WIDGET (props->priv->bvw));
 }
 
 static void
